@@ -1,4 +1,6 @@
 def add_one(number):
     return number + 1
 def hi():
-    return "hi123"
\ No newline at end of file
+    return "hi123"
+def version():
+    return '0.0.2'
\ No newline at end of file
